@@ -164,7 +164,6 @@ PluginFinishType LibarchivePlugin::extractFiles(const QList<FileEntry> &files, c
 
     QString extractDst;
     bool bDlnfs = m_common->isSubpathOfDlnfs(options.strTargetPath);
-
     // Iterate through all entries in archive.
     int iIndex = 0;     // 存储索引值
     while (!QThread::currentThread()->isInterruptionRequested() && (archive_read_next_header(m_archiveReader.data(), &entry) == ARCHIVE_OK)) {
@@ -214,7 +213,7 @@ PluginFinishType LibarchivePlugin::extractFiles(const QList<FileEntry> &files, c
         // 提取:过滤选中的文件以及选中目录下所有文件
         if (!extractAll) {
             bool flag = false;
-            foreach (auto tmp, qAsConst(files)) {
+            foreach (auto tmp, files) {
                 if (tmp.isDirectory) {
                     if (entryName.startsWith(tmp.strFullPath)) {
                         flag = true;
@@ -261,7 +260,6 @@ PluginFinishType LibarchivePlugin::extractFiles(const QList<FileEntry> &files, c
         bool bLongName = false;
         QString tempFilePathName;
         QString strOriginName = entryName;
-
         if(!bDlnfs) {
             QString sDir = m_common->handleLongNameforPath(strFilePath, entryName, m_mapLongDirName, m_mapRealDirValue);
             if(sDir.length() > 0) {
@@ -788,9 +786,15 @@ void LibarchivePlugin::emitEntryForIndex(archive_entry *aentry)
     m_archiveEntryStat.strFullPath = entryName;
 
     // 文件名
-    const QStringList pieces = m_archiveEntryStat.strFullPath.split(QLatin1Char('/'), QString::SkipEmptyParts);
+    const QStringList pieces = m_archiveEntryStat.strFullPath.split(QLatin1Char('/'),
+                                                                    #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+                                                                    QString::SkipEmptyParts);
+                                                                    #else
+                                                                    Qt::SkipEmptyParts);
+                                                                    #endif
     m_archiveEntryStat.strFileName = pieces.last();
 
+
     // 文件真实大小（文件夹显示项）
     if (m_archiveEntryStat.isDirectory) {
         m_archiveEntryStat.qSize = 0;
