@@ -32,6 +32,7 @@ PluginManager::PluginManager(QObject *parent)
 
 PluginManager &PluginManager::get_instance()
 {
+    // qDebug() << "Getting PluginManager instance";
 #ifndef Q_ATOMIC_POINTER_TEST_AND_SET_IS_SOMETIMES_NATIVE
     if (!QAtomicPointer<PluginManager>::isTestAndSetNative()) //运行时检测
         qInfo() << "Error: TestAndSetNative not supported!";
@@ -43,6 +44,7 @@ PluginManager &PluginManager::get_instance()
      * 不会被重新排序。
      */
     if (m_instance.testAndSetOrdered(nullptr, nullptr)) { //第一次检测
+        qDebug() << "Creating new PluginManager instance";
         QMutexLocker locker(&m_mutex);//加互斥锁。
 
         m_instance.testAndSetOrdered(nullptr, new PluginManager);//第二次检测。
@@ -53,11 +55,13 @@ PluginManager &PluginManager::get_instance()
 
 QVector<Plugin *> PluginManager::installedPlugins() const
 {
+    qDebug() << "Getting installed plugins, count:" << m_plugins.size();
     return m_plugins;
 }
 
 QVector<Plugin *> PluginManager::availablePlugins() const
 {
+    qDebug() << "Getting available plugins";
     QVector<Plugin *> availablePlugins;
     for (Plugin *plugin : qAsConst(m_plugins)) {
         if (plugin->isValid()) {
@@ -65,11 +69,13 @@ QVector<Plugin *> PluginManager::availablePlugins() const
         }
     }
 
+    qDebug() << "Found" << availablePlugins.size() << "available plugins";
     return availablePlugins;
 }
 
 QVector<Plugin *> PluginManager::availableWritePlugins() const
 {
+    qDebug() << "Getting available write plugins";
     QVector<Plugin *> availableWritePlugins;
     const auto plugins = availablePlugins();
     for (Plugin *plugin : plugins) {
@@ -78,11 +84,13 @@ QVector<Plugin *> PluginManager::availableWritePlugins() const
         }
     }
 
+    qDebug() << "Found" << availableWritePlugins.size() << "available write plugins";
     return availableWritePlugins;
 }
 
 QVector<Plugin *> PluginManager::enabledPlugins() const
 {
+    qDebug() << "Getting enabled plugins";
     QVector<Plugin *> enabledPlugins;
     for (Plugin *plugin : qAsConst(m_plugins)) {
         if (plugin->isEnabled()) {
@@ -90,43 +98,62 @@ QVector<Plugin *> PluginManager::enabledPlugins() const
         }
     }
 
+    qDebug() << "Found" << enabledPlugins.size() << "enabled plugins";
     return enabledPlugins;
 }
 
 QVector<Plugin *> PluginManager::preferredPluginsFor(const CustomMimeType &mimeType)
 {
+    qDebug() << "Getting preferred plugins for mime type:" << mimeType.name();
     const auto mimeName = mimeType.name();
     if (m_preferredPluginsCache.contains(mimeName)) {
+        qDebug() << "Using cached preferred plugins for:" << mimeName;
         return m_preferredPluginsCache.value(mimeName);
     }
 
     const auto plugins = preferredPluginsFor(mimeType, false);
     m_preferredPluginsCache.insert(mimeName, plugins);
+    qDebug() << "Cached" << plugins.size() << "preferred plugins for:" << mimeName;
     return plugins;
 }
 
 QVector<Plugin *> PluginManager::preferredWritePluginsFor(const CustomMimeType &mimeType) const
 {
+    qDebug() << "Getting preferred write plugins for mime type:" << mimeType.name();
     return preferredPluginsFor(mimeType, true);
 }
 
 Plugin *PluginManager::preferredPluginFor(const CustomMimeType &mimeType)
 {
+    qDebug() << "Getting preferred plugin for mime type:" << mimeType.name();
     const QVector<Plugin *> preferredPlugins = preferredPluginsFor(mimeType);
-    return preferredPlugins.isEmpty() ? new Plugin() : preferredPlugins.first();
+    if (preferredPlugins.isEmpty()) {
+        qWarning() << "No preferred plugin found for mime type:" << mimeType.name();
+        return new Plugin();
+    }
+    qDebug() << "Using preferred plugin:" << preferredPlugins.first()->metaData().pluginId();
+    return preferredPlugins.first();
 }
 
 Plugin *PluginManager::preferredWritePluginFor(const CustomMimeType &mimeType) const
 {
+    qDebug() << "Getting preferred write plugin for mime type:" << mimeType.name();
     const QVector<Plugin *> preferredWritePlugins = preferredWritePluginsFor(mimeType);
-    return preferredWritePlugins.isEmpty() ? new Plugin() : preferredWritePlugins.first();
+    if (preferredWritePlugins.isEmpty()) {
+        qWarning() << "No preferred write plugin found for mime type:" << mimeType.name();
+        return new Plugin();
+    }
+    qDebug() << "Using preferred write plugin:" << preferredWritePlugins.first()->metaData().pluginId();
+    return preferredWritePlugins.first();
 }
 
 QStringList PluginManager::supportedMimeTypes(MimeSortingMode mode) const
 {
+    qDebug() << "Getting supported mime types with mode:" << mode;
     QSet<QString> supported;
     QMimeDatabase db;
     const auto plugins = availablePlugins();
+    qDebug() << "Processing" << plugins.size() << "available plugins";
     for (Plugin *plugin : plugins) {
         const auto mimeTypes = plugin->metaData().mimeTypes();
         for (const auto &mimeType : mimeTypes) {
@@ -138,31 +165,38 @@ QStringList PluginManager::supportedMimeTypes(MimeSortingMode mode) const
 
     // Remove entry for lrzipped tar if lrzip executable not found in path.
     if (QStandardPaths::findExecutable(QStringLiteral("lrzip")).isEmpty()) {
+        qDebug() << "Removing lrzip-compressed-tar support - executable not found";
         supported.remove(QStringLiteral("application/x-lrzip-compressed-tar"));
     }
 
     // Remove entry for lz4-compressed tar if lz4 executable not found in path.
     if (QStandardPaths::findExecutable(QStringLiteral("lz4")).isEmpty()) {
+        qDebug() << "Removing lz4-compressed-tar support - executable not found";
         supported.remove(QStringLiteral("application/x-lz4-compressed-tar"));
     }
 
     // Remove entry for lzo-compressed tar if libarchive not linked against lzo and lzop executable not found in path.
     if (!libarchiveHasLzo() && QStandardPaths::findExecutable(QStringLiteral("lzop")).isEmpty()) {
+        qDebug() << "Removing tzo support - no lzo support and lzop not found";
         supported.remove(QStringLiteral("application/x-tzo"));
     }
 
     if (mode == SortByComment) {
+        qDebug() << "Sorting mime types by comment";
         return sortByComment(supported);
     }
 
+    qDebug() << "Found" << supported.size() << "supported mime types";
     return supported.values();
 }
 
 QStringList PluginManager::supportedWriteMimeTypes(MimeSortingMode mode) const
 {
+    qDebug() << "Getting supported write mime types with mode:" << mode;
     QSet<QString> supported;
     QMimeDatabase db;
     const auto plugins = availableWritePlugins();
+    qDebug() << "Processing" << plugins.size() << "available write plugins";
     for (Plugin *plugin : plugins) {
         const auto mimeTypes = plugin->metaData().mimeTypes();
         for (const auto &mimeType : mimeTypes) {
@@ -174,29 +208,36 @@ QStringList PluginManager::supportedWriteMimeTypes(MimeSortingMode mode) const
 
     // Remove entry for lrzipped tar if lrzip executable not found in path.
     if (QStandardPaths::findExecutable(QStringLiteral("lrzip")).isEmpty()) {
+        qDebug() << "Removing lrzip-compressed-tar write support - executable not found";
         supported.remove(QStringLiteral("application/x-lrzip-compressed-tar"));
     }
 
     // Remove entry for lz4-compressed tar if lz4 executable not found in path.
     if (QStandardPaths::findExecutable(QStringLiteral("lz4")).isEmpty()) {
+        qDebug() << "Removing lz4-compressed-tar write support - executable not found";
         supported.remove(QStringLiteral("application/x-lz4-compressed-tar"));
     }
 
     // Remove entry for lzo-compressed tar if libarchive not linked against lzo and lzop executable not found in path.
     if (!libarchiveHasLzo() && QStandardPaths::findExecutable(QStringLiteral("lzop")).isEmpty()) {
+        qDebug() << "Removing tzo write support - no lzo support and lzop not found";
         supported.remove(QStringLiteral("application/x-tzo"));
     }
 
+    qDebug() << "Removing ISO image write support";
     supported.remove(QStringLiteral("application/x-iso9660-image"));
 
+    qDebug() << "Removing RAR write support";
     supported.remove(QStringLiteral("application/vnd.rar"));
     supported.remove(QStringLiteral("application/x-rar"));
 //    supported.remove(QStringLiteral("application/octet-stream"));
 
     if (mode == SortByComment) {
+        qDebug() << "Sorting write mime types by comment";
         return sortByComment(supported);
     }
 
+    qDebug() << "Found" << supported.size() << "supported write mime types";
     return supported.values();
 }
 
@@ -234,6 +275,7 @@ QVector<Plugin *> PluginManager::filterBy(const QVector<Plugin *> &plugins, cons
 
 void PluginManager::setFileSize(qint64 size)
 {
+    qDebug() << "Setting file size to:" << size;
     m_filesize = size;
 }
 
@@ -264,8 +306,10 @@ void PluginManager::loadPlugins()
 
 QVector<Plugin *> PluginManager::preferredPluginsFor(const CustomMimeType &mimeType, bool readWrite) const
 {
+    qDebug() << "Getting preferred plugins for mime type:" << mimeType.name() << "readWrite:" << readWrite;
     QVector<Plugin *> preferredPlugins = filterBy((readWrite ? availableWritePlugins() : availablePlugins()), mimeType);
 
+    qDebug() << "Sorting" << preferredPlugins.size() << "plugins by priority";
     std::sort(preferredPlugins.begin(), preferredPlugins.end(), [](Plugin * p1, Plugin * p2) {
         return p1->priority() > p2->priority();
     });
@@ -296,11 +340,13 @@ QVector<Plugin *> PluginManager::preferredPluginsFor(const CustomMimeType &mimeT
 //        }
 //    }
 
+    qDebug() << "Returning" << preferredPlugins.size() << "preferred plugins";
     return preferredPlugins;
 }
 
 QStringList PluginManager::sortByComment(const QSet<QString> &mimeTypes)
 {
+    qDebug() << "Sorting" << mimeTypes.size() << "mime types by comment";
     QMap<QString, QString> map;
 
     // Initialize the QMap to sort by comment.
@@ -315,6 +361,7 @@ QStringList PluginManager::sortByComment(const QSet<QString> &mimeTypes)
         sortedMimeTypes << value;
     }
 
+    qDebug() << "Sorted mime types, result count:" << sortedMimeTypes.size();
     return sortedMimeTypes;
 }
 
