@@ -40,23 +40,27 @@ DCORE_USE_NAMESPACE
 TypeLabel::TypeLabel(QWidget *parent)
     : DFrame(parent)
 {
+    qDebug() << "TypeLabel constructor";
     setFrameShape(QFrame::NoFrame);
 }
 
 TypeLabel::~TypeLabel()
 {
-
+    qDebug() << "TypeLabel destructor";
 }
 
 void TypeLabel::mousePressEvent(QMouseEvent *event)
 {
+    qDebug() << "TypeLabel mousePressEvent";
     emit labelClickEvent(event);
     DFrame::mousePressEvent(event);
 }
 
 void TypeLabel::paintEvent(QPaintEvent *event)
 {
+    // qDebug() << "TypeLabel paintEvent";
     if (hasFocus() && (m_reson & (Qt::TabFocusReason | Qt::BacktabFocusReason | Qt::PopupFocusReason))) {
+        // qDebug() << "TypeLabel paintEvent has focus";
         DStylePainter painter(this);
         DStyle *style = dynamic_cast<DStyle *>(DApplication::style());
         QStyleOptionFrame opt;
@@ -75,12 +79,14 @@ void TypeLabel::paintEvent(QPaintEvent *event)
 
 void TypeLabel::focusInEvent(QFocusEvent *event)
 {
+    // qDebug() << "TypeLabel focusInEvent";
     m_reson = event->reason();
     DFrame::focusInEvent(event);
 }
 
 void TypeLabel::focusOutEvent(QFocusEvent *event)
 {
+    // qDebug() << "TypeLabel focusOutEvent";
     m_reson = event->reason();
     DFrame::focusOutEvent(event);
 }
@@ -197,6 +203,7 @@ void CompressSettingPage::refreshMenu()
 
 void CompressSettingPage::initUI()
 {
+    qDebug() << "initUI";
     // 左侧界面
     m_pTypePixmapLbl = new DLabel(this);
     m_pClickLbl = new TypeLabel(this);
@@ -385,6 +392,7 @@ void CompressSettingPage::initUI()
 
 void CompressSettingPage::initConnections()
 {
+    qDebug() << "initConnections";
     connect(m_pClickLbl, SIGNAL(labelClickEvent(QMouseEvent *)), this, SLOT(slotShowRightMenu(QMouseEvent *)));
     connect(m_pTypeMenu, &DMenu::triggered, this, &CompressSettingPage::slotTypeChanged);
     connect(m_pFileNameEdt, &DLineEdit::textChanged, this, &CompressSettingPage::slotRefreshFileNameEdit);
@@ -399,6 +407,7 @@ void CompressSettingPage::initConnections()
 
 void CompressSettingPage::setTypeImage(const QString &strType)
 {
+    qDebug() << "setTypeImage: " << strType;
     QFileIconProvider provider;
     QIcon icon = provider.icon(QFileInfo("temp." + strType));
 
@@ -412,16 +421,19 @@ bool CompressSettingPage::checkFileNameVaild(const QString &strText)
 
     // 文件名为空返回错误
     if (strArchiveName.length() == 0) {
+        qWarning() << "File name is empty";
         return false;
     }
 
     // 文件名过长返回错误
     if (strArchiveName.length() > 255) {
+        qWarning() << "File name is too long";
         return false;
     }
 
     // 如果文件名中包含"/"，返回错误
     if (strArchiveName.contains(QDir::separator())) {
+        qWarning() << "File name contains separator";
         return false;
     }
 
@@ -430,17 +442,20 @@ bool CompressSettingPage::checkFileNameVaild(const QString &strText)
 
 void CompressSettingPage::setEncryptedEnabled(bool bEnabled)
 {
+    qDebug() << "setEncryptedEnabled: " << bEnabled;
     // 设置加密是否可用
     m_pEncryptedLbl->setEnabled(bEnabled);
     m_pPasswordEdt->setEnabled(bEnabled);
 
     if (!bEnabled) {
+        qDebug() << "Disabling list encryption";
         setListEncryptionEnabled(bEnabled);
     }
 }
 
 void CompressSettingPage::slotEchoModeChanged(bool bEchoOn)
 {
+    qDebug() << "CompressSettingPage::slotEchoModeChanged" << bEchoOn;
     // 根据明暗码决定是否屏蔽输入法
     m_pPasswordEdt->lineEdit()->setAttribute(Qt::WA_InputMethodEnabled, bEchoOn);
 }
@@ -451,29 +466,35 @@ void CompressSettingPage::slotEchoModeChanged(bool bEchoOn)
  */
 void CompressSettingPage::setListEncryptionEnabled(bool bEnabled)
 {
+    qDebug() << "setListEncryptionEnabled: " << bEnabled;
     m_pListEncryptionLbl->setEnabled(bEnabled);
     m_pListEncryptionBtn->setEnabled(bEnabled);
 }
 
 void CompressSettingPage::setSplitEnabled(bool bEnabled)
 {
+    qDebug() << "setSplitEnabled: " << bEnabled;
     m_pSplitCkb->setEnabled(bEnabled);  // 设置分卷勾选框是否可用
 
     // 如果不分卷，取消勾选，清空分卷数据
     if (!bEnabled) {
+        qDebug() << "Disabling split";
         m_pSplitCkb->setCheckState(Qt::Unchecked);
         m_pSplitValueEdt->setEnabled(bEnabled);
         m_pSplitValueEdt->clear();
         m_pSplitValueEdt->setValue(0.0);
     } else {
+        qDebug() << "Enabling split";
         m_pSplitValueEdt->setEnabled(m_pSplitCkb->isChecked());
     }
 }
 
 void CompressSettingPage::refreshCompressLevel(const QString &strType)
 {
+    qDebug() << "refreshCompressLevel: " << strType;
 #ifdef DTKCORE_CLASS_DConfigFile
     if(m_isOrderMode) {
+        qDebug() << "Order mode is enabled";
         // 其余格式支持设置压缩方式
         // 设置压缩方式可用
         m_pCompressLevelCmb->setEnabled(true);
@@ -481,22 +502,28 @@ void CompressSettingPage::refreshCompressLevel(const QString &strType)
         if(!m_dconfig) return;
         DConfig *dconfig = (DConfig *)m_dconfig;
         if(strType == "7z") {
+            qDebug() << "Refresh compress level for 7z";
             if(dconfig && dconfig->isValid() && dconfig->keyList().contains("special7zCompressor")){
+                        qDebug() << "Setting 7z compress level from config";
                         int nMethod = dconfig->value("special7zCompressor").toInt();
                         m_pCompressLevelCmb->setCurrentIndex(nMethod);
                     }
         } else if(strType == "jar") {
+            qDebug() << "Refresh compress level for jar";
             if(dconfig && dconfig->isValid() && dconfig->keyList().contains("specialJarCompressor")){
+                        qDebug() << "Setting jar compress level from config";
                         int nMethod = dconfig->value("specialJarCompressor").toInt();
                         m_pCompressLevelCmb->setCurrentIndex(nMethod);
                     }
         } else if(strType == "tar") {
+            qDebug() << "Refresh compress level for tar";
             // tar只有存储功能
             m_pCompressLevelCmb->setCurrentIndex(0);
             // 设置压缩方式不可用
             m_pCompressLevelCmb->setEnabled(false);
             m_pCompressLevelLbl->setEnabled(false);
         } else if(strType == "tar.bz2") {
+            qDebug() << "Refresh compress level for tar.bz2";
             if(dconfig && dconfig->isValid() && dconfig->keyList().contains("specialTarbz2Compressor")){
                         int nMethod = dconfig->value("specialTarbz2Compressor").toInt();
                         m_pCompressLevelCmb->setCurrentIndex(nMethod);
@@ -578,6 +605,7 @@ void CompressSettingPage::refreshCompressLevel(const QString &strType)
 
 void CompressSettingPage::setCommentEnabled(bool bEnabled)
 {
+    qDebug() << "setCommentEnabled: " << bEnabled;
     m_pCommentLbl->setEnabled(bEnabled);
     m_pCommentEdt->setEnabled(bEnabled);
     // 注释不可用时,清除注释
@@ -587,23 +615,28 @@ void CompressSettingPage::setCommentEnabled(bool bEnabled)
 
 bool CompressSettingPage::checkCompressOptionValid()
 {
+    qDebug() << "Checking compress options validity";
     if (!checkFileNameVaild(m_pFileNameEdt->text())) { // 检查文件名是否有效
+        qWarning() << "Invalid file name";
         showWarningDialog(tr("Invalid file name"));
         return false;
     }
 
     QFileInfo fInfo(m_pSavePathEdt->text());
     if ((m_pSavePathEdt->text().remove(" ")).isEmpty()) { // 检查是否已经选择保存路径
+        qWarning() << "Save path is empty";
         showWarningDialog(tr("Please enter the path"));
         return false;
     }
 
     if (!fInfo.exists()) { // 检查选择保存路径是否存在
+        qWarning() << "Save path does not exist";
         showWarningDialog(tr("The path does not exist, please retry"));
         return false;
     }
 
     if (!(fInfo.isWritable() && fInfo.isExecutable())) { // 检查一选择保存路径是否有权限
+        qWarning() << "No write/execute permission for save path";
         showWarningDialog(tr("You do not have permission to save files here, please change and retry"));
         return false;
     }
@@ -612,6 +645,7 @@ bool CompressSettingPage::checkCompressOptionValid()
             && (fabs(m_pSplitValueEdt->value()) < std::numeric_limits<double>::epsilon()
                 || (((m_qFileSize / 1024 / 1024) / (m_pSplitValueEdt->value())) > 200))
             && (m_strMimeType.contains("7z") || m_strMimeType.contains("zip"))) { // 最多允许分卷数量为200卷
+        qWarning() << "Too many volumes requested";
         showWarningDialog(tr("Too many volumes, please change and retry"));
         return false;
     }
@@ -620,12 +654,14 @@ bool CompressSettingPage::checkCompressOptionValid()
     for (int i = 0; i < m_listFiles.count(); i++) {
         QFileInfo file(m_listFiles.at(i));
         if (!file.exists()) {  // 待压缩文件已经不存在
+            qWarning() << "File to be compressed does not exist:" << file.absoluteFilePath();
             bResult = false;
             showWarningDialog(tr("%1 does not exist on the disk, please check and try again").arg(file.absoluteFilePath()), file.absoluteFilePath());
             return false;
         }
 
         if (!file.isReadable()) {
+            qWarning() << "No read permission for file to be compressed:" << file.absoluteFilePath();
             bResult = false;
             showWarningDialog(tr("You do not have permission to compress %1").arg(file.absoluteFilePath()), file.absoluteFilePath());
             return false;
@@ -643,12 +679,15 @@ bool CompressSettingPage::checkCompressOptionValid()
 
 bool CompressSettingPage::checkFile(const QString &path)
 {
+    qDebug() << "Checking file access:" << path;
     QFileInfo fileInfo(path);
 
     if (!fileInfo.exists()) {  // 待压缩文件已经不存在
         if (fileInfo.isSymLink()) {
+            qWarning() << "Symlink target does not exist:" << path;
             showWarningDialog(tr("The original file of %1 does not exist, please check and try again").arg(fileInfo.absoluteFilePath()), fileInfo.absoluteFilePath());
         } else {
+            qWarning() << "File does not exist:" << path;
             showWarningDialog(tr("%1 does not exist on the disk, please check and try again").arg(fileInfo.absoluteFilePath()), fileInfo.absoluteFilePath());
         }
 
@@ -656,11 +695,13 @@ bool CompressSettingPage::checkFile(const QString &path)
     }
 
     if (!fileInfo.isReadable()) {
+        qWarning() << "File not readable:" << path;
         showWarningDialog(tr("You do not have permission to compress %1").arg(fileInfo.absoluteFilePath()), fileInfo.absoluteFilePath());
         return false;
     }
 
     if (fileInfo.isDir()) {
+        qDebug() << "Checking directory contents:" << path;
         QDir dir(path);
         // 遍历文件夹下的子文件夹
         QFileInfoList listInfo = dir.entryInfoList(QDir::AllEntries | QDir::System
@@ -680,6 +721,7 @@ bool CompressSettingPage::checkFile(const QString &path)
 
 int CompressSettingPage::showWarningDialog(const QString &msg, const QString &strToolTip)
 {
+    qWarning() << "Showing warning dialog:" << msg;
     // 使用封装好的提示对话框
     TipDialog dialog(this);
     return dialog.showDialog(msg, tr("OK", "button"), DDialog::ButtonNormal, strToolTip);
@@ -687,6 +729,7 @@ int CompressSettingPage::showWarningDialog(const QString &msg, const QString &st
 
 void CompressSettingPage::setDefaultName(const QString &strName)
 {
+    qDebug() << "Setting default archive name to:" << strName;
     m_pFileNameEdt->setText(strName);
     QLineEdit *qfilename = m_pFileNameEdt->lineEdit();
     qfilename->selectAll();
@@ -695,6 +738,7 @@ void CompressSettingPage::setDefaultName(const QString &strName)
 
 void CompressSettingPage::initConfig()
 {
+    qDebug() << "Initializing config";
 #ifdef DTKCORE_CLASS_DConfigFile
     QProcess process;
     process.start("dmidecode");
@@ -705,6 +749,7 @@ void CompressSettingPage::initConfig()
     for (const QString &line : lines) {
         if (line.contains("String 4", Qt::CaseInsensitive)) {
             m_isOrderMode = line.contains("PGUX", Qt::CaseInsensitive) || line.contains("FXK11", Qt::CaseInsensitive);
+            qDebug() << "Order mode detected:" << m_isOrderMode;
         }
     }
     process.close();
@@ -714,6 +759,7 @@ void CompressSettingPage::initConfig()
 
 void CompressSettingPage::slotShowRightMenu(QMouseEvent *e)
 {
+    qDebug() << "Showing context menu";
     Q_UNUSED(e)
 
     // 设置菜单弹出位置
@@ -739,27 +785,32 @@ void CompressSettingPage::slotTypeChanged(QAction *action)
     m_pCpuCmb->setCurrentIndex(0);
 
     if (0 == selectType.compare("tar.7z")) {       // tar.7z支持普通/列表加密，不支持分卷
+        qDebug() << "Type changed to tar.7z";
         setEncryptedEnabled(true);
         setListEncryptionEnabled(true);
         setSplitEnabled(false);
         setCommentEnabled(false);
     } else if (0 == selectType.compare("7z")) {     // 7z支持普通/列表加密。支持分卷
+        qDebug() << "Type changed to 7z";
         setEncryptedEnabled(true);
         setListEncryptionEnabled(true);
         setSplitEnabled(true);
         setCommentEnabled(false);
     } else if (0 == selectType.compare("zip")) {    // zip支持普通加密，不支持列表加密，支持分卷，支持注释，但不同时支持分卷和注释
+        qDebug() << "Type changed to zip";
         setEncryptedEnabled(true);
         setListEncryptionEnabled(false);
         setSplitEnabled(true);
         setCommentEnabled(!m_pSplitCkb->isChecked()); // 不同时支持分卷和注释
     } else {                                // 其余格式不支持加密，不支持分卷
+        qDebug() << "Type changed to other format:" << selectType;
         setEncryptedEnabled(false);
         setListEncryptionEnabled(false);
         setSplitEnabled(false);
         setCommentEnabled(false);
 
         if (0 == selectType.compare("tar.gz")) {
+            qDebug() << "Enabling CPU thread selection for tar.gz";
             m_pCpuLbl->setEnabled(true);
             m_pCpuCmb->setEnabled(true);
             m_pCpuCmb->setCurrentIndex(m_pCpuCmb->count() - 1);
@@ -771,6 +822,7 @@ void CompressSettingPage::slotTypeChanged(QAction *action)
 
 void CompressSettingPage::slotRefreshFileNameEdit()
 {
+    qDebug() << "Refreshing file name edit style";
     DPalette plt = DPaletteHelper::instance()->palette(m_pFileNameEdt);
 
     if (!m_pFileNameEdt->text().isEmpty()) {
@@ -789,6 +841,7 @@ void CompressSettingPage::slotRefreshFileNameEdit()
 
 void CompressSettingPage::slotAdvancedEnabled(bool bEnabled)
 {
+    qDebug() << "Advanced options enabled:" << bEnabled;
     // bug103712  滚动区域内widget高度发生变化导致页面闪动   页面变化前先设置widget大小
     if (bEnabled) {
         m_pRightScroll->widget()->setFixedHeight(SCROLL_MAX);
@@ -809,6 +862,7 @@ void CompressSettingPage::slotAdvancedEnabled(bool bEnabled)
 
     // 不启用高级选项时清空界面数据
     if (!bEnabled) {
+        qDebug() << "Clearing advanced options";
         m_pPasswordEdt->clear();
         m_pListEncryptionBtn->setChecked(false);
         m_pSplitCkb->setChecked(false);
@@ -825,6 +879,7 @@ void CompressSettingPage::slotAdvancedEnabled(bool bEnabled)
             if(dconfig && dconfig->isValid() && dconfig->keyList().contains("specialCpuTarGzCompressor")){
                 int nCpu = dconfig->value("specialCpuTarGzCompressor").toInt();
                 m_pCpuCmb->setCurrentIndex(nCpu);
+                 qDebug() << "Setting CPU threads for tar.gz from config:" << nCpu;
             }
         }
 #endif
@@ -833,6 +888,7 @@ void CompressSettingPage::slotAdvancedEnabled(bool bEnabled)
 
 void CompressSettingPage::slotSplitEdtEnabled()
 {
+    qDebug() << "Split checkbox state changed, isChecked:" << m_pSplitCkb->isChecked();
     if(m_pSplitValueEdt->hasFocus() || m_pCommentEdt->hasFocus()) {
         parentWidget()->setFocus();
     }
@@ -955,8 +1011,10 @@ void CompressSettingPage::slotCompressClicked()
 
 void CompressSettingPage::slotCommentTextChanged()
 {
+    qDebug() << "Comment text changed";
     QString savetext = m_pCommentEdt->toPlainText();
     if (savetext.size() > MAXCOMMENTLEN) { //限制最多注释MAXCOMMENTLEN个字
+        qDebug() << "Comment exceeds max length, truncating";
         // 保留前MAXCOMMENTLEN个注释字符
         m_pCommentEdt->setText(savetext.left(MAXCOMMENTLEN));
 
@@ -969,11 +1027,13 @@ void CompressSettingPage::slotCommentTextChanged()
 
 void CompressSettingPage::slotPasswordChanged()
 {
+    qDebug() << "Password text changed";
     QRegularExpression reg("^[\\x00-\\x80\\x{4e00}-\\x{9fa5}]+$");
     QString pwdin = m_pPasswordEdt->lineEdit()->text();
     QString pwdout;
 
     if (!pwdin.isEmpty() && !reg.match(pwdin).hasMatch()) {
+        qDebug() << "Password contains invalid characters, filtering";
         for (int i = 0; i < pwdin.length(); ++i) {
             if (reg.match(pwdin.at(i)).hasMatch()) {
                 pwdout.append(pwdin.at(i));
@@ -988,11 +1048,13 @@ void CompressSettingPage::slotPasswordChanged()
 
 CustomPushButton *CompressSettingPage::getCompressBtn() const
 {
+    // qDebug() << "getCompressBtn called";
     return m_pCompressBtn;
 }
 
 QString CompressSettingPage::getComment() const
 {
+    qDebug() << "getComment called";
     // m_pCommentEdt不可用时就返回空字符串，表示该压缩格式(除zip格式外)不支持添加注释
     if (nullptr != m_pCommentEdt) {
         return m_pCommentEdt->isEnabled() ? m_pCommentEdt->toPlainText() : QString("");
@@ -1007,6 +1069,7 @@ bool CompressSettingPage::eventFilter(QObject *watched, QEvent *event)
         if (QEvent::KeyPress == event->type()) {
             QKeyEvent *keyEvent = dynamic_cast<QKeyEvent *>(event);
             if (Qt::Key_Enter == keyEvent->key() || Qt::Key_Return == keyEvent->key()) { //响应"回车键"
+                // qDebug() << "Enter key pressed on type label, showing menu";
                 m_pTypeMenu->popup(m_pCompressTypeLbl->mapToGlobal(m_pCompressTypeLbl->pos())); // 设置菜单弹出位置
                 m_pTypeMenu->setFocus(); // 切换焦点
                 return true;
@@ -1024,10 +1087,12 @@ bool CompressSettingPage::eventFilter(QObject *watched, QEvent *event)
 
 bool CompressSettingPage::isOrderMode()
 {
+    // qDebug() << "isOrderMode called, returning:" << m_isOrderMode;
     return m_isOrderMode;
 }
 
 TypeLabel *CompressSettingPage::getClickLbl() const
 {
+    // qDebug() << "getClickLbl called";
     return m_pClickLbl;
 }
